==> jc-1.4.0.tar.gz: org/xml/sax/helpers/XMLReaderAdapter__24AttributesAdapter.h <==
// final class org.xml.sax.helpers.XMLReaderAdapter$AttributesAdapter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2c721ff746fc882e org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter_H_
#define _JC_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Attributes$object;
struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object;

// Typedefs
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_refs	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_refs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_nonrefs	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_nonrefs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$refs	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$refs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$nonrefs	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$nonrefs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object;

typedef const struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vmethods	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vmethods;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtable	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtable;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype;

// Constructors
extern void _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$_init$463717208ca5fb92(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object *);

// Virtual methods
extern jint _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getName$01e3e07467e6e4a7(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getType$7237ce0c39ef435a(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getType$ed1616ac5c5cd5c7(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getValue$9165a29c353738af(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getValue$05ab1fbc2191f4a2(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_java_lang_String$object *);
extern void _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$setAttributes$4c05843371eb74a2(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getName$01e3e07467e6e4a7;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getType$7237ce0c39ef435a;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getType$ed1616ac5c5cd5c7;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getValue$9165a29c353738af;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getValue$05ab1fbc2191f4a2;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$setAttributes$4c05843371eb74a2;

// Virtual methods structure
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *);
	struct _jc_java_lang_String$object	*(*getName$01e3e07467e6e4a7)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint);
	struct _jc_java_lang_String$object	*(*getType$7237ce0c39ef435a)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint);
	struct _jc_java_lang_String$object	*(*getType$ed1616ac5c5cd5c7)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*getValue$9165a29c353738af)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint);
	struct _jc_java_lang_String$object	*(*getValue$05ab1fbc2191f4a2)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_java_lang_String$object *);
	void	(*setAttributes$4c05843371eb74a2)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_object *);
};

// Vtable
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vmethods	org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter;
};

// Vtype
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype {
	_jc_type			type;
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_refs {
	struct _jc_object	*attributes;
	struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object	*this;
};

// Reference instance fields (object)
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$refs {
    _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_refs	org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_nonrefs	org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter;
};

// Object instance structure
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object {
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype	*vtype;
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$class_object;

#endif	/* _JC_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/helpers/XMLReaderAdapter__24AttributesAdapter.h <==
// final class org.xml.sax.helpers.XMLReaderAdapter$AttributesAdapter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2c721ff746fc882e org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter_H_
#define _JC_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Attributes$object;
struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object;

// Typedefs
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_refs	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_refs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_nonrefs	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_nonrefs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$refs	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$refs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$nonrefs	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$nonrefs;
typedef struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object;

typedef const struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vmethods	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vmethods;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtable	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtable;
typedef const struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype;

// Constructors
extern void _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$_init$463717208ca5fb92(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getName$01e3e07467e6e4a7(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getType$7237ce0c39ef435a(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getType$ed1616ac5c5cd5c7(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getValue$9165a29c353738af(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$getValue$05ab1fbc2191f4a2(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method$setAttributes$4c05843371eb74a2(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getName$01e3e07467e6e4a7;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getType$7237ce0c39ef435a;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getType$ed1616ac5c5cd5c7;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getValue$9165a29c353738af;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$getValue$05ab1fbc2191f4a2;
extern _jc_method _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$method_info$setAttributes$4c05843371eb74a2;

// Virtual methods structure
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$01e3e07467e6e4a7)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getType$7237ce0c39ef435a)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getType$ed1616ac5c5cd5c7)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getValue$9165a29c353738af)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getValue$05ab1fbc2191f4a2)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setAttributes$4c05843371eb74a2)(_jc_env *, struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vmethods	org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter;
};

// Vtype
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype {
	_jc_type			type;
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_refs {
	struct _jc_object	*attributes;
	struct _jc_org_xml_sax_helpers_XMLReaderAdapter$object	*this;
};

// Reference instance fields (object)
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$refs {
    _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_refs	org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$sub_nonrefs	org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter;
};

// Object instance structure
struct _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$object {
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype	*vtype;
	_jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$vtype _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter$class_object;

#endif	/* _JC_org_xml_sax_helpers_XMLReaderAdapter__24AttributesAdapter_H_ */
